@@ -1,7 +1,7 @@
 package App::riap;
 
-our $DATE = '2015-09-03'; # DATE
-our $VERSION = '0.33'; # VERSION
+our $DATE = '2016-02-03'; # DATE
+our $VERSION = '0.34'; # VERSION
 
 use 5.010001;
 use strict;
@@ -622,7 +622,9 @@ sub catch_comp {
     my $meta = $res->[2];
 
     my ($words, $cword) = @{ Complete::Bash::parse_cmdline(
-        $line, $start+length($word)) };
+        $line, $start+length($word), {truncate_current_word=>1}) };
+    ($words, $cword) = @{ Complete::Bash::join_wordbreak_words(
+        $words, $cword) };
     shift @$words; $cword--; # strip program name
     $opts = {};
     $res = Perinci::Sub::Complete::complete_cli_arg(
@@ -688,7 +690,9 @@ sub _install_cmds {
             my ($word, $line, $start) = @_;
             local $self->{_in_completion} = 1;
             my ($words, $cword) = @{ Complete::Bash::parse_cmdline(
-                $line, $start+length($word), '=') };
+                $line, $start+length($word), {truncate_current_word=>1}) };
+            ($words, $cword) = @{ Complete::Bash::join_wordbreak_words(
+                $words, $cword) };
             shift @$words; $cword--; # strip program name
             $opts = {};
             my $res = Perinci::Sub::Complete::complete_cli_arg(
@@ -733,7 +737,7 @@ App::riap - Riap command-line client shell
 
 =head1 VERSION
 
-version 0.33
+version 0.34
 
 =head1 SYNOPSIS
 
@@ -755,7 +759,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
