@@ -1,7 +1,7 @@
 package App::riap::Commands;
 
-our $DATE = '2015-09-03'; # DATE
-our $VERSION = '0.33'; # VERSION
+our $DATE = '2016-02-03'; # DATE
+our $VERSION = '0.34'; # VERSION
 
 use 5.010;
 use strict;
@@ -169,7 +169,6 @@ sub ls {
 
             };
             $resmeta = {
-                "format_options" => {any=>{table_column_orders => [$ff]}},
                 "table.fields"   => $ff,
             },
         } else {
@@ -320,8 +319,7 @@ sub set {
                 default => $shell->known_settings->{$_}{schema}[1]{default},
             };
         }
-        my $rfo = {table_column_orders=>[[qw/name summary value default/]]};
-        [200, "OK", $res, {format_options=>{any=>$rfo}}];
+        [200, "OK", $res, {'table.fields' => [qw/name summary value default/]}];
     }
 }
 
@@ -552,7 +550,7 @@ App::riap::Commands - riap shell commands
 
 =head1 VERSION
 
-version 0.33
+version 0.34
 
 =for Pod::Coverage .+
 
@@ -562,7 +560,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
